@@ -8,20 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_kms._jsii
-import aws_cdk.aws_sns._jsii
-import aws_cdk.aws_sns_subscriptions._jsii
-import aws_cdk.aws_sqs._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-sns-sqs",
-    "1.89.0",
+    "2.10.0",
     __name__[0:-6],
-    "aws-sns-sqs@1.89.0.jsii.tgz",
+    "aws-sns-sqs@2.10.0.jsii.tgz",
 )
 
 __all__ = [
